package MT::Plugin::SimpleAuth;
use strict;
use MT;
use MT::Plugin;

our $VERSION = '0.1';
use base qw( MT::Plugin );

###################################### Init Plugin #####################################

@MT::Plugin::SimpleAuth::ISA = qw(MT::Plugin);

my $plugin = new MT::Plugin::SimpleAuth({
    id => 'SimpleAuth',
    key => 'simpleauth',
    name => 'SimpleAuth',
    author_name => 'Junnama Noda',
    author_link => 'http://junnama.alfasado.net/online/',
    description => 'Simple Authorization for MT',
    'version' => $VERSION,
    system_config_template => 'simple_auth.tmpl',
    settings => new MT::PluginSettings([
        ['base', { Default => '/path/to/htdocs' }],
        ['suffix', { Default => '.deny' }],
        ['auth_dirs', { Default => '/path/to/htdocs/auth' }],
        ['indexes', { Default => 'index.html,index.htm' }],
        ['error_file', { Default => '/path/to/htdocs/404.html' }],
    ]),
});

MT->add_plugin($plugin);

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        callbacks => {
            'build_file'
                => \&_build_file,
            'build_page'
                => \&_build_file,
            'cms_upload_file'
                => \&_build_file,
            'cms_upload_image'
                => \&_created_thumbnail,
        },
   });
}

##################################### Main Routine ####################################

sub _created_thumbnail {
    my ($eh, %params) = @_;
    my $file = $params{file};
    my $type = $params{type};
    if ($type eq 'thumbnail') {
        my $auth_dirs = $plugin->get_config_value('auth_dirs');
        my $auth_flg;
        my @dirs = split("\n", $auth_dirs);
        foreach my $ck (@dirs) {
            if ($file =~ /^$ck/) {
                $auth_flg = 1;
                last;
            }
        }
        if ($auth_flg) {
            if (-f $file) {
                my $suffix = $plugin->get_config_value('suffix');
                rename $file, $file.$suffix;
                #return 0;
            }
            if (-f $file) {
                unlink $file;
                #return 0;
            }
        }
        #return 1;
    }
}

sub _build_file {
    my ($eh, %args) = @_;
    my $file = $args{'file'};
    my $auth_dirs = $plugin->get_config_value('auth_dirs');
    my $auth_flg;
    my @dirs = split("\n", $auth_dirs);
    foreach my $ck (@dirs) {
        if ($file =~ /^$ck/) {
            $auth_flg = 1;
            last;
        }
    }
    if ($auth_flg) {
        if (-f $file) {
            my $suffix = $plugin->get_config_value('suffix');
            rename $file, $file.$suffix;
            #return 0;
        }
        if (-f $file) {
            unlink $file;
            #return 0;
        }
    }
    #return 1;
}

1;